==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/mt.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d 'ta'\N{U+2019} MMM, y G",
    GyMMMd => "d MMM, y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M-d",
    MMM => "LLL",
    MMMEd => "E, d 'ta'\N{U+2019} MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d 'ta'\N{U+2019} MMMM",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d 'ta'\N{U+2019} MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d 'ta'\N{U+2019} MMM, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ - y",
    yQQQQ => "QQQQ - y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "mt",
  date_format_full => "EEEE, d 'ta'\N{U+2019} MMMM y",
  date_format_long => "d 'ta'\N{U+2019} MMMM y",
  date_format_medium => "dd MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Tne",
    "Tli",
    "Erb",
    "\N{U+0126}am",
    "\N{U+0120}im",
    "Sib",
    "\N{U+0126}ad"
  ],
  day_format_narrow => [
    "T",
    "Tl",
    "Er",
    "\N{U+0126}m",
    "\N{U+0120}m",
    "Sb",
    "\N{U+0126}d"
  ],
  day_format_wide => [
    "It-Tnejn",
    "It-Tlieta",
    "L-Erbg\N{U+0127}a",
    "Il-\N{U+0126}amis",
    "Il-\N{U+0120}img\N{U+0127}a",
    "Is-Sibt",
    "Il-\N{U+0126}add"
  ],
  day_stand_alone_abbreviated => [
    "Tne",
    "Tli",
    "Erb",
    "\N{U+0126}am",
    "\N{U+0120}im",
    "Sib",
    "\N{U+0126}ad"
  ],
  day_stand_alone_narrow => [
    "Tn",
    "Tl",
    "Er",
    "\N{U+0126}m",
    "\N{U+0120}m",
    "Sb",
    "\N{U+0126}d"
  ],
  day_stand_alone_wide => [
    "It-Tnejn",
    "It-Tlieta",
    "L-Erbg\N{U+0127}a",
    "Il-\N{U+0126}amis",
    "Il-\N{U+0120}img\N{U+0127}a",
    "Is-Sibt",
    "Il-\N{U+0126}add"
  ],
  era_abbreviated => [
    "QK",
    "WK"
  ],
  era_narrow => [
    "QK",
    "WK"
  ],
  era_wide => [
    "Qabel Kristu",
    "Wara Kristu"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Maltese",
  month_format_abbreviated => [
    "Jan",
    "Fra",
    "Mar",
    "Apr",
    "Mej",
    "\N{U+0120}un",
    "Lul",
    "Aww",
    "Set",
    "Ott",
    "Nov",
    "Di\N{U+010b}"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "\N{U+0120}",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Jannar",
    "Frar",
    "Marzu",
    "April",
    "Mejju",
    "\N{U+0120}unju",
    "Lulju",
    "Awwissu",
    "Settembru",
    "Ottubru",
    "Novembru",
    "Di\N{U+010b}embru"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Fra",
    "Mar",
    "Apr",
    "Mej",
    "\N{U+0120}un",
    "Lul",
    "Aww",
    "Set",
    "Ott",
    "Nov",
    "Di\N{U+010b}"
  ],
  month_stand_alone_narrow => [
    "Jn",
    "Fr",
    "Mz",
    "Ap",
    "Mj",
    "\N{U+0120}n",
    "Lj",
    "Aw",
    "St",
    "Ob",
    "Nv",
    "D\N{U+010b}"
  ],
  month_stand_alone_wide => [
    "Jannar",
    "Frar",
    "Marzu",
    "April",
    "Mejju",
    "\N{U+0120}unju",
    "Lulju",
    "Awwissu",
    "Settembru",
    "Ottubru",
    "Novembru",
    "Di\N{U+010b}embru"
  ],
  name => "Maltese",
  native_language => "Malti",
  native_name => "Malti",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "1el kwart",
    "2ni kwart",
    "3et kwart",
    "4ba\N{U+2019} kwart"
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "1el kwart",
    "2ni kwart",
    "3et kwart",
    "4ba\N{U+2019} kwart"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/mt.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d 'ta'\N{U+2019} MMM, y G",
    GyMMMd => "d MMM, y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M-d",
    MMM => "LLL",
    MMMEd => "E, d 'ta'\N{U+2019} MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d 'ta'\N{U+2019} MMMM",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d 'ta'\N{U+2019} MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d 'ta'\N{U+2019} MMM, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ - y",
    yQQQQ => "QQQQ - y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mt",
  date_format_full => "EEEE, d 'ta'\N{U+2019} MMMM y",
  date_format_long => "d 'ta'\N{U+2019} MMMM y",
  date_format_medium => "dd MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Tne",
    "Tli",
    "Erb",
    "\N{U+0126}am",
    "\N{U+0120}im",
    "Sib",
    "\N{U+0126}ad",
  ],
  day_format_narrow => [
    "T",
    "Tl",
    "Er",
    "\N{U+0126}m",
    "\N{U+0120}m",
    "Sb",
    "\N{U+0126}d",
  ],
  day_format_wide => [
    "It-Tnejn",
    "It-Tlieta",
    "L-Erbg\N{U+0127}a",
    "Il-\N{U+0126}amis",
    "Il-\N{U+0120}img\N{U+0127}a",
    "Is-Sibt",
    "Il-\N{U+0126}add",
  ],
  day_stand_alone_abbreviated => [
    "Tne",
    "Tli",
    "Erb",
    "\N{U+0126}am",
    "\N{U+0120}im",
    "Sib",
    "\N{U+0126}ad",
  ],
  day_stand_alone_narrow => [
    "Tn",
    "Tl",
    "Er",
    "\N{U+0126}m",
    "\N{U+0120}m",
    "Sb",
    "\N{U+0126}d",
  ],
  day_stand_alone_wide => [
    "It-Tnejn",
    "It-Tlieta",
    "L-Erbg\N{U+0127}a",
    "Il-\N{U+0126}amis",
    "Il-\N{U+0120}img\N{U+0127}a",
    "Is-Sibt",
    "Il-\N{U+0126}add",
  ],
  era_abbreviated => [
    "QK",
    "WK",
  ],
  era_narrow => [
    "QK",
    "WK",
  ],
  era_wide => [
    "Qabel Kristu",
    "Wara Kristu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Maltese",
  month_format_abbreviated => [
    "Jan",
    "Fra",
    "Mar",
    "Apr",
    "Mej",
    "\N{U+0120}un",
    "Lul",
    "Aww",
    "Set",
    "Ott",
    "Nov",
    "Di\N{U+010b}",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "\N{U+0120}",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Jannar",
    "Frar",
    "Marzu",
    "April",
    "Mejju",
    "\N{U+0120}unju",
    "Lulju",
    "Awwissu",
    "Settembru",
    "Ottubru",
    "Novembru",
    "Di\N{U+010b}embru",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Fra",
    "Mar",
    "Apr",
    "Mej",
    "\N{U+0120}un",
    "Lul",
    "Aww",
    "Set",
    "Ott",
    "Nov",
    "Di\N{U+010b}",
  ],
  month_stand_alone_narrow => [
    "Jn",
    "Fr",
    "Mz",
    "Ap",
    "Mj",
    "\N{U+0120}n",
    "Lj",
    "Aw",
    "St",
    "Ob",
    "Nv",
    "D\N{U+010b}",
  ],
  month_stand_alone_wide => [
    "Jannar",
    "Frar",
    "Marzu",
    "April",
    "Mejju",
    "\N{U+0120}unju",
    "Lulju",
    "Awwissu",
    "Settembru",
    "Ottubru",
    "Novembru",
    "Di\N{U+010b}embru",
  ],
  name => "Maltese",
  native_language => "Malti",
  native_name => "Malti",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1el kwart",
    "2ni kwart",
    "3et kwart",
    "4ba\N{U+2019} kwart",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1el kwart",
    "2ni kwart",
    "3et kwart",
    "4ba\N{U+2019} kwart",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
